@@ -12,7 +12,7 @@ from .gaps_spaces import (
     RE_SUPPLIED, SuppliedProcessor
 )
 from .foreign import RE_FOREIGN, ForeignProcessor
-from .to_xml import TEIPostprocessor
+from .to_tei import TEIPostprocessor
 from .misc import HetaProcessor, RE_HETA
 from .exceptions import LeidenPlusSyntaxError
 
@@ -63,7 +63,10 @@ class LeidenEscape(Extension):
 
 
 def leiden_plus(content, **kwargs):
-    return markdown(content, extensions = [LeidenPlus(**kwargs)])
+    extensions = [LeidenPlus(**kwargs)]
+    if not kwargs.get('strict', False):
+        extensions.append('tables')
+    return markdown(content, extensions=extensions)
 
 def leiden_escape(content, **kwargs):
-    return markdown(content, extensions = [LeidenEscape(**kwargs)])
+    return markdown(content, extensions = [LeidenEscape(**kwargs), 'tables'])
